@@ -5,12 +5,12 @@
 
 
 
-use std::str::FromStr;
-use std::fmt::Display;
 
 use combine::char::*;
 use combine::combinator::*;
 use combine::primitives::{ParseError, ParseResult, Parser, Stream};
+use std::fmt::Display;
+use std::str::FromStr;
 
 type CustomCharParser<I> = Expected<Satisfy<I, fn(char) -> bool>>;
 
@@ -34,10 +34,18 @@ fn test_split_bom() {
     let bom2 = unsafe { ::std::str::from_utf8_unchecked(bom2_vec) };
 
     // Rust doesn't seem to let us create a BOM as str in a safe way.
-    assert_eq!(split_bom(unsafe { ::std::str::from_utf8_unchecked(&[0xEF, 0xBB, 0xBF, 'a' as u8, 'b' as u8, 'c' as u8]) }),
-               (bom1, "abc"));
-    assert_eq!(split_bom(unsafe { ::std::str::from_utf8_unchecked(&[0xFE, 0xFF, 'd' as u8, 'e' as u8, 'g' as u8]) }),
-               (bom2, "deg"));
+    assert_eq!(
+        split_bom(unsafe {
+            ::std::str::from_utf8_unchecked(&[0xEF, 0xBB, 0xBF, 'a' as u8, 'b' as u8, 'c' as u8])
+        }),
+        (bom1, "abc")
+    );
+    assert_eq!(
+        split_bom(unsafe {
+            ::std::str::from_utf8_unchecked(&[0xFE, 0xFF, 'd' as u8, 'e' as u8, 'g' as u8])
+        }),
+        (bom2, "deg")
+    );
     assert_eq!(split_bom("bla"), ("", "bla"));
     assert_eq!(split_bom(""), ("", ""));
 }
@@ -46,7 +54,8 @@ fn test_split_bom() {
 #[inline]
 #[allow(trivial_casts)]
 pub fn ws<I>() -> CustomCharParser<I>
-    where I: Stream<Item = char>
+where
+    I: Stream<Item = char>,
 {
     fn f(c: char) -> bool {
         c == ' ' || c == '\t'
@@ -56,7 +65,8 @@ pub fn ws<I>() -> CustomCharParser<I>
 
 /// Matches a positive or negative intger number.
 pub fn number_i64<I>(input: I) -> ParseResult<i64, I>
-    where I: Stream<Item = char>
+where
+    I: Stream<Item = char>,
 {
     (optional(char('-')), many1(digit()))
         .map(|(a, c): (Option<_>, String)| {
@@ -73,12 +83,18 @@ pub fn number_i64<I>(input: I) -> ParseResult<i64, I>
 
 /// Create a single-line-error string from a combine parser error.
 pub fn parse_error_to_string<I, R, P>(p: ParseError<I>) -> String
-    where I: Stream<Item = char, Range = R, Position = P>,
-          R: PartialEq + Clone + Display,
-          P: Ord + Display
+where
+    I: Stream<Item = char, Range = R, Position = P>,
+    R: PartialEq + Clone + Display,
+    P: Ord + Display,
 {
-    p.to_string().trim().lines().fold("".to_string(),
-                                      |a, b| if a.is_empty() { b.to_string() } else { a + "; " + b })
+    p.to_string().trim().lines().fold("".to_string(), |a, b| {
+        if a.is_empty() {
+            b.to_string()
+        } else {
+            a + "; " + b
+        }
+    })
 }
 
 
@@ -88,7 +104,8 @@ pub fn parse_error_to_string<I, R, P>(p: ParseError<I>) -> String
 /// original file. Two consecutive filler parts (their strings) can be merged. This function abstracts over the
 /// specific file part type.
 pub fn dedup_string_parts<T, F>(v: Vec<T>, mut extract_fn: F) -> Vec<T>
-    where F: FnMut(&mut T) -> Option<&mut String>
+where
+    F: FnMut(&mut T) -> Option<&mut String>,
 {
 
     let mut result = Vec::new();
@@ -135,10 +152,10 @@ pub fn get_lines_non_destructive(s: &str) -> Vec<SplittedLine> {
                 if rest.starts_with("\r\n") {
                     result.push((line, "\r\n".to_string()));
                     rest = &rest[2..];
-                } else if rest.starts_with("\n") {
+                } else if rest.starts_with('\n') {
                     result.push((line, "\n".to_string()));
                     rest = &rest[1..];
-                } else if rest.starts_with("\r") {
+                } else if rest.starts_with('\r') {
                     // we only treat this as valid line ending to avoid error handling
                     result.push((line, "\r".to_string()));
                     rest = &rest[1..];
@@ -156,7 +173,10 @@ pub fn get_lines_non_destructive(s: &str) -> Vec<SplittedLine> {
 fn get_lines_non_destructive_test0() {
     let lines = ["", "aaabb", "aaabb\r\nbcccc\n\r\n ", "aaabb\r\nbcccc"];
     for &full_line in lines.into_iter() {
-        let joined: String = get_lines_non_destructive(full_line).into_iter().flat_map(|(s1, s2)| vec![s1, s2].into_iter()).collect();
+        let joined: String = get_lines_non_destructive(full_line)
+            .into_iter()
+            .flat_map(|(s1, s2)| vec![s1, s2].into_iter())
+            .collect();
         assert_eq!(full_line, joined);
     }
 }
@@ -167,10 +187,18 @@ fn get_lines_non_destructive_test0() {
 pub fn trim_non_destructive(s: &str) -> (String, String, String) {
     let (begin, rest) = trim_left(s);
     let (end, rest2) = trim_left(&rest.chars().rev().collect::<String>());
-    (begin, rest2.chars().rev().collect(), end.chars().rev().collect())
+    (
+        begin,
+        rest2.chars().rev().collect(),
+        end.chars().rev().collect(),
+    )
 }
 
 /// Splits a string in whitespace string and the rest "   hello " -> ("   ", "hello ").
 fn trim_left(s: &str) -> (String, String) {
-    (many(ws()), many(try(any())), eof()).map(|t| (t.0, t.1)).parse(s).expect("the trim parser should accept any input").0
+    (many(ws()), many(try(any())), eof())
+        .map(|t| (t.0, t.1))
+        .parse(s)
+        .expect("the trim parser should accept any input")
+        .0
 }
