@@ -5,18 +5,18 @@
 
 
 
-use {SubtitleEntry, SubtitleFile};
-use errors::Result as SubtitleParserResult; // the crate wide error type (we use a custom error type here)
-use super::common::*;
-use timetypes::{TimeDelta, TimePoint, TimeSpan};
-use self::errors::ErrorKind::*;
 use self::errors::*;
-
-use std::iter::once;
+use self::errors::ErrorKind::*; // the crate wide error type (we use a custom error type here)
+use super::common::*;
+use {SubtitleEntry, SubtitleFile};
 
 use combine::char::*;
 use combine::combinator::*;
 use combine::primitives::Parser;
+use errors::Result as SubtitleParserResult;
+
+use std::iter::once;
+use timetypes::{TimeDelta, TimePoint, TimeSpan};
 
 /// `.idx`-parser-specific errors
 #[allow(missing_docs)]
@@ -59,11 +59,9 @@ pub struct IdxFile {
 impl IdxFile {
     fn new(v: Vec<IdxFilePart>) -> IdxFile {
         // cleans up multiple fillers after another
-        let new_file_parts = dedup_string_parts(v, |part: &mut IdxFilePart| {
-            match *part {
-                IdxFilePart::Filler(ref mut text) => Some(text),
-                _ => None,
-            }
+        let new_file_parts = dedup_string_parts(v, |part: &mut IdxFilePart| match *part {
+            IdxFilePart::Filler(ref mut text) => Some(text),
+            _ => None,
         });
         IdxFile { v: new_file_parts }
     }
@@ -74,16 +72,19 @@ impl SubtitleFile for IdxFile {
         let timings: Vec<_> = self.v
                                   .iter()
                                   .filter_map(|file_part| match *file_part {
-                                      IdxFilePart::Filler(_) => None,
-                                      IdxFilePart::Timestamp(t) => Some(t),
-                                  })
+            IdxFilePart::Filler(_) => None,
+            IdxFilePart::Timestamp(t) => Some(t),
+        })
                                   .collect();
 
         Ok(match timings.last() {
             Some(&last_timing) => {
                 // .idx files do not store timespans. Every subtitle is shown until the next subtitle
                 // starts. Mpv shows the last subtile for exactly one minute.
-                let next_timings = timings.iter().cloned().skip(1).chain(once(last_timing + TimeDelta::from_mins(1)));
+                let next_timings = timings.iter().cloned().skip(1).chain(once(
+                    last_timing +
+                        TimeDelta::from_mins(1),
+                ));
                 timings.iter()
                        .cloned()
                        .zip(next_timings)
@@ -118,12 +119,14 @@ impl SubtitleFile for IdxFile {
         // timing to string like "00:03:28:308"
         let fn_timing_to_string = |t: TimePoint| {
             let p = if t.msecs() < 0 { -t } else { t };
-            format!("{}{:02}:{:02}:{:02}:{:03}",
-                    if t.msecs() < 0 { "-" } else { "" },
-                    p.hours(),
-                    p.mins_comp(),
-                    p.secs_comp(),
-                    p.msecs_comp())
+            format!(
+                "{}{:02}:{:02}:{:02}:{:03}",
+                if t.msecs() < 0 { "-" } else { "" },
+                p.hours(),
+                p.mins_comp(),
+                p.secs_comp(),
+                p.msecs_comp()
+            )
         };
 
         let fn_file_part_to_string = |part: &IdxFilePart| {
@@ -134,10 +137,7 @@ impl SubtitleFile for IdxFile {
             }
         };
 
-        let result: String = self.v
-                                 .iter()
-                                 .map(fn_file_part_to_string)
-                                 .collect();
+        let result: String = self.v.iter().map(fn_file_part_to_string).collect();
 
         Ok(result.into_bytes())
     }
@@ -149,7 +149,7 @@ impl SubtitleFile for IdxFile {
 impl IdxFile {
     /// Parse a `.idx` subtitle string to `IdxFile`.
     pub fn parse(s: &str) -> SubtitleParserResult<IdxFile> {
-        match IdxFile::parse_inner(&s) {
+        match IdxFile::parse_inner(s) {
             Ok(v) => Ok(v),
             Err(e) => Err(e.into()),
         }
@@ -179,19 +179,34 @@ impl IdxFile {
             return Ok(vec![IdxFilePart::Filler(s)]);
         }
 
-        (many(ws()), string("timestamp:"), many(ws()), many(or(digit(), token(':'))), many(try(any())), eof())
-            .map(|(ws1, s1, ws2, timestamp_str, s2, _): (String, &str, String, String, String, ())| -> Result<Vec<IdxFilePart>> {
-                let mut result = Vec::<IdxFilePart>::new();
-                result.push(IdxFilePart::Filler(ws1));
-                result.push(IdxFilePart::Filler(s1.to_string()));
-                result.push(IdxFilePart::Filler(ws2));
-                result.push(IdxFilePart::Timestamp(Self::parse_timestamp(line_num, timestamp_str.as_str())?));
-                result.push(IdxFilePart::Filler(s2.to_string()));
-                Ok(result)
-            })
-            .parse(s.as_str())
-            .map_err(|e| IdxLineParseError(line_num, parse_error_to_string(e)))?
-            .0
+        (
+            many(ws()),
+            string("timestamp:"),
+            many(ws()),
+            many(or(digit(), token(':'))),
+            many(try(any())),
+            eof(),
+        )
+        .map(|(ws1, s1, ws2, timestamp_str, s2, _): (String,
+                                                &str,
+                                                String,
+                                                String,
+                                                String,
+                                                ())|
+         -> Result<Vec<IdxFilePart>> {
+            let mut result = Vec::<IdxFilePart>::new();
+            result.push(IdxFilePart::Filler(ws1));
+            result.push(IdxFilePart::Filler(s1.to_string()));
+            result.push(IdxFilePart::Filler(ws2));
+            result.push(IdxFilePart::Timestamp(
+                Self::parse_timestamp(line_num, timestamp_str.as_str())?,
+            ));
+            result.push(IdxFilePart::Filler(s2.to_string()));
+            Ok(result)
+        })
+        .parse(s.as_str())
+        .map_err(|e| IdxLineParseError(line_num, parse_error_to_string(e)))?
+        .0
     }
 
     /// Parse an .idx timestamp like `00:41:36:961`.
